@@ -1,5 +1,7 @@
 #' Creates plot of model results (uncertainties optional)
 #'
+#' `r lifecycle::badge("experimental")`
+#'
 #' All parameter combinations and exposure patterns are simulated and the mean
 #' of predictions is derived for a single study. The uncertainty is
 #' passed to the function due to computation time. Results are displayed by
@@ -250,6 +252,8 @@ plot_sd <- function(model_base,
 
 #' Creates a PPC plot for a single dataset
 #'
+#' `r lifecycle::badge("experimental")`
+#'
 #' A sample of parameters representing the uncertainty within the dataset
 #' is passed to the function. All parameter combinations and exposure patterns
 #' are simulated and the range of predicted frond numbers is derived for a
@@ -355,12 +359,15 @@ plot_ppc <- function(rs_mean,
 
 #' Create PPC plot for one or more datasets
 #'
-#' The function expects a data.frame with four mandatory and one optional
+#' `r lifecycle::badge("experimental")`
+#'
+#' The function expects a data.frame with five mandatory and one optional
 #' column. The mandatory columns are as follows:
 #' - `pred`: mean of predictions e.g. frond number for lemna
 #' - `max`: maximum of predictions
 #' - `min`: minimum of predictions
 #' - `obs`: observations
+#' - `PPC`: color code
 #' The optional column is to be named `study` and contains a study identifier.
 #' If more than one study identifier is present in the table, individual
 #' studies will be plotted in different colors and a legend will be displayed.
@@ -370,8 +377,7 @@ plot_ppc <- function(rs_mean,
 #' @param table `data.frame` containing return values of calls to `plot_ppc()`
 #' @param xy_lim optional `numeric`, limits of x and y axis for plotting
 #' @return a ggplot2 plot object
-#' @global obs pred study min max
-
+#' @autoglobal
 plot_ppc_combi <- function(table, xy_lim = NULL) {
   if (!is.data.frame(table)) stop("table not a data.frame")
 
@@ -425,17 +431,16 @@ plot_ppc_combi <- function(table, xy_lim = NULL) {
     "%"
   )
 
-  plot <- ggplot2::ggplot() +
+  plot <- ggplot2::ggplot(table) +
     ggplot2::geom_abline(linetype = "dashed") +
     ggplot2::geom_linerange(
       ggplot2::aes(obs,
-        ymin = obs$min,
-        ymax = obs$max,
-        color = obs$PPC
+        ymin = min,
+        ymax = max,
+        color = PPC
       ),
       alpha = 0.7,
-      linewidth = 1.1,
-      data = table
+      linewidth = 1.1
     ) +
     ggplot2::scale_color_identity()
 
@@ -445,8 +450,7 @@ plot_ppc_combi <- function(table, xy_lim = NULL) {
         pred,
         color = study
       ),
-      size = 1.5,
-      data = table
+      size = 1.5
     ) +
     ggplot2::coord_cartesian(xlim = c(0, xy_lim), ylim = c(0, xy_lim)) +
     ggplot2::labs(x = "Observed", y = "Predicted", title = title) +
@@ -461,6 +465,8 @@ plot_ppc_combi <- function(table, xy_lim = NULL) {
 
 #' Plot EPx values
 #'
+#' `r lifecycle::badge("experimental")`
+#'
 #' @param EPx_ts the result of `epx_mtw`, ie. a tibble with window.start,
 #' window.end, endpoint, level and EPx
 #' @param exposure_ts an exposure time series with columns for time 't' and
@@ -552,6 +558,10 @@ plot_epx <- function(EPx_ts, exposure_ts, draw = TRUE, time_col = "time", conc_c
 
 #' Creates a prediction plot for one effect scenario
 #'
+#' `r lifecycle::badge("deprecated")`
+#'
+#' This function has been deprecated and replaced by the generic [plot()].
+#'
 #' Sometimes it is helpful if the user can plot results of one effect
 #' scenario. This is for instance the case for test simulations or predictions
 #' for one profile. This function runs the simulation for one effect scenario
@@ -565,8 +575,12 @@ plot_epx <- function(EPx_ts, exposure_ts, draw = TRUE, time_col = "time", conc_c
 #' @export
 #'
 #' @examples
-#' plot_scenario(metsulfuron)
+#' # Please use `plot()` instead
+#' metsulfuron %>%
+#'   simulate() %>%
+#'   plot()
 plot_scenario <- function(model_base, plot_col = 2, trial_number = NULL) {
+  lifecycle::deprecate_warn("1.3.1", "plot_scenario()", "plot()")
 
   # set name of run
   if (is.null(trial_number)) {
@@ -592,5 +606,4 @@ plot_scenario <- function(model_base, plot_col = 2, trial_number = NULL) {
     obs_mean = NULL,
     plot_col = plot_col
   )
-
 }
