@@ -121,7 +121,7 @@ setGeneric("simulate", function(x, ...) standardGeneric("simulate"), signature="
 #' default for all models using sliding exposure windows
 #' @rdname simulate
 #' @include class-EffectScenario.R
-setMethod("simulate", "EffectScenario", function(x, ...) solver(scenario=x, ...))
+setMethod("simulate", "EffectScenario", function(x, ...) simulate_scenario(x, ...))
 
 #' @rdname simulate
 #' @include class-Transferable.R
@@ -131,6 +131,15 @@ setMethod("simulate", "Transferable", function(x, ...) simulate_transfer(scenari
 #' @include class-ScenarioSequence.R
 setMethod("simulate", "ScenarioSequence", function(x, ...) simulate_seq(seq=x, ...))
 
+
+# Wrapper for solver function to enforce setting of a S3 class for all simulation
+# results.
+simulate_scenario <- function(x, ...) {
+  rs <- solver(scenario=x, ...)
+  class(rs) <- c("cvasi.simulate", class(rs))
+  rs
+}
+
 # Simulate a scenario where (biomass) quantities are transferred and reset
 # at certain time points
 #
@@ -148,7 +157,7 @@ setMethod("simulate", "ScenarioSequence", function(x, ...) simulate_seq(seq=x, .
 # @return data.frame
 simulate_transfer <- function(scenario, times, in_sequence=FALSE, ...) {
   if(!has_transfer(scenario)) # shortcut if no transfers were defined
-    return(solver(scenario, times=times, ...))
+    return(simulate_scenario(scenario, times=times, ...))
 
   if(missing(times))
     times <- scenario@times
@@ -187,7 +196,7 @@ simulate_transfer <- function(scenario, times, in_sequence=FALSE, ...) {
 
   # if no transfers occur -> early exit
   if(length(tr_points) == 0 & !ends_on_transfer)
-    return(solver(scenario, times=times, ...))
+    return(simulate_scenario(scenario, times=times, ...))
 
   # transfer time points must be contained in output time points
   if(length(setdiff(tr_points, times)) > 0)
@@ -242,6 +251,7 @@ simulate_transfer <- function(scenario, times, in_sequence=FALSE, ...) {
       attr(df, "next_init") <- tail(df, 1)[names(scenario@init)]
   }
   rownames(df) <- NULL
+  class(df) <- c("cvasi.simulate", class(df))
   df
 }
 
@@ -295,16 +305,20 @@ simulate_seq <- function(seq, times, ...) {
   }
   attr(df, "next_init") <- NULL
   rownames(df) <- NULL
+  class(df) <- c("cvasi.simulate", class(df))
   df
 }
 
-#' Batch simulation of several effect scenarios
+#' Batch simulation using multiple exposure series
 #'
-#' An effect scenario contains only one exposure level. Consequently, the
-#' simulation of an effect scenario (e.g. metsulfuron %>% simulate will return
-#' the results for one exposure level only). However, in a laboratory experiment
-#' examining the effects of different exposure levels on a biological system,
-#' a batch simulation approach would involve running multiple simulations with
+#' `r lifecycle::badge("experimental")`
+#' A convenience function to simulate a single base scenario with one or more
+#' exposure series. This aims at reproducing the setup and results of common
+#' effect studies.
+#'
+#' A scenario contains only one exposure series. However, laboratory experiments
+#' commonly examine the effects of multiple exposure levels on a biological system.
+#' A batch simulation approach would involve running multiple simulations with
 #' varying exposure or treatment conditions. To illustrate, if the objective is
 #' to examine the impact of a substance on cell growth, the simulation model
 #' could be designed to replicate the cell growth dynamics under varying
@@ -317,25 +331,22 @@ simulate_seq <- function(seq, times, ...) {
 #'
 #' @param model_base effect scenario object with mean parameters
 #' @param treatments treatments exposure levels as data frame (time, conc, trial)
-#' @param param_sample data.frame with parameter sample
+#' @param param_sample *deprecated* parameter, no longer in use
 #' @return a `data.frame` with simulation results
 #' @export
 #' @examples
+#' t1 <- data.frame(time=0:10, conc=0, trial="control")  # 1st treatment level
+#' t2 <- data.frame(time=0:10, conc=1, trial="T1")       # 2nd treatment level
+#' treatments <- rbind(t1, t2)
 #'
-#' exposure <- data.frame(time = Schmitt2013$t,
-#'             conc = Schmitt2013$conc,
-#'            trial = Schmitt2013$ID)
-#'
-#' sim_result <- simulate_batch(model_base = metsulfuron,
-#'                             treatments = exposure)
-#'
-#'
-#'
-#'
-simulate_batch <- function(model_base,
-                           treatments,
-                           param_sample = NULL
-                           ) {
+#' metsulfuron %>%
+#'   simulate_batch(treatments)
+simulate_batch <- function(model_base, treatments, param_sample=deprecated()) {
+  if(is_present(param_sample)) {
+    if(!is.null(param_sample)) {
+      lifecycle::deprecate_stop("1.3.0", "simulate_batch(param_sample)")
+    }
+  }
   # Check if columns 'time' and 'conc' exist
   if(!("time" %in% colnames(treatments)) || !("conc" %in% colnames(treatments))) {
     stop("Columns 'time' and/or 'conc' not found in treatments dataframe.")
@@ -358,31 +369,15 @@ simulate_batch <- function(model_base,
   # simulate
   df <- data.frame()
   df_one_run <- data.frame()
-  if (is.null(param_sample)) { # run best fit params for all treatments
-    simulated_results <- purrr::map(list_of_effect_sets, ~ .x %>%
-                                      simulate(sim_times = sim_times))
-    # add trial name
-    simulated_results <- purrr::map2(
-      simulated_results,
-      exp_levels,
-      ~ dplyr::mutate(.x, trial = .y)
-    )
-    df <- dplyr::bind_rows(simulated_results)
-  } else { # run parameter sample for all treatments
-    for (i in 1:nrow(param_sample)) {
-      simulated_results <- purrr::map(list_of_effect_sets, ~ .x %>%
-                                        set_param(param_sample[i, ]) %>%
-                                        simulate(sim_times = sim_times))
-      # add trial name
-      simulated_results <- purrr::map2(
-        simulated_results,
-        exp_levels,
-        ~ dplyr::mutate(.x, trial = .y)
-      )
-      # bind
-      df_one_run <- dplyr::bind_rows(simulated_results)
-      df <- rbind(df, df_one_run)
-    }
-  }
+  simulated_results <- purrr::map(list_of_effect_sets, ~ .x %>%
+                                    simulate())
+  # add trial name
+  simulated_results <- purrr::map2(
+    simulated_results,
+    exp_levels,
+    ~ dplyr::mutate(.x, trial = .y)
+  )
+  df <- dplyr::bind_rows(simulated_results)
+  class(df) <- c("cvasi.simulate", class(df))
   return(df)
 }
